@@ -1,12 +1,12 @@
 package MarpaX::Simple;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Marpa::R2;
 use UUID::Random;
@@ -169,7 +169,7 @@ MarpaX::Simple - Generate Marpa-based parser
 
 =head1 VERSION
 
-This document describes version 0.04 of MarpaX::Simple (from Perl distribution MarpaX-Simple), released on 2015-01-03.
+This document describes version 0.05 of MarpaX::Simple (from Perl distribution MarpaX-Simple), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -221,8 +221,9 @@ function call: C<gen_parser>.
 
 =head2 gen_parser(%args) -> code
 
-Generate Marpa-based parser.
+{en_US Generate Marpa-based parser}.
 
+{en_US 
 One of C<slif_grammar>, C<grammar_class_file>, C<grammar_module_file>,
 C<grammar_file>, C<grammar> must be specified for the input grammar. The arguments
 will be checked in that order. The simplest would be to use grammar text inlined
@@ -233,54 +234,59 @@ the lowest overhead since you specify SLIF grammar that are already
 instantiated. See also the related Dist::Zilla plugin
 C<Dist::Zilla::Plugin::InsertMarpaSLIFGrammar>.
 
+}
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
 =item * B<actions> => I<hash>
 
-Supply code for actions specified in the grammar.
+{en_US Supply code for actions specified in the grammar}.
 
 =item * B<grammar> => I<str>
 
-Marpa BNF input grammar text.
+{en_US Marpa BNF input grammar text}.
 
 =item * B<grammar_class_file> => I<str>
 
-Marpa BNF input grammar file, resolved using File::ShareDir's class_file().
+{en_US Marpa BNF input grammar file, resolved using File::ShareDir's class_file()}.
 
 =item * B<grammar_file> => I<str>
 
-Marpa BNF input grammar file.
+{en_US Marpa BNF input grammar file}.
 
 =item * B<grammar_module_file> => I<str>
 
-Marpa BNF input grammar file, resolved using File::ShareDir's module_file().
+{en_US Marpa BNF input grammar file, resolved using File::ShareDir's module_file()}.
 
 =item * B<slif_grammar> => I<obj>
 
-SLIF input grammar.
+{en_US SLIF input grammar}.
 
+{en_US 
 This input-grammar argument is checked first because it is the most ready-to-use
 form and has the least overhead. The other input-grammar arguments require
 creating the C<Marpa::R2::Scanless::G> object first from the Marpa BNF DSL
 grammar.
+}
 
 =item * B<too_many_earley_items> => I<int>
 
-Will be passed to recognizer's constructor.
+{en_US Will be passed to recognizer's constructor}.
 
 =item * B<trace_terminals> => I<bool>
 
-Will be passed to recognizer's constructor.
+{en_US Will be passed to recognizer's constructor}.
 
 =item * B<trace_values> => I<bool>
 
-Will be passed to recognizer's constructor.
+{en_US Will be passed to recognizer's constructor}.
 
 =back
 
 Return value:  (code)
+
 =head1 SEE ALSO
 
 L<Marpa::R2>
